# Mkdocs Flux Theme

This is a minimalist theme for [mkdocs] made by [@yqshao][yqshao] for his
projects. The look and feel is inspired by the [miniflux] feed reader. The site
serves as a demo of the theme, you could also find the manual that showcase
available options.

[mkdocs]: https://www.mkdocs.org/
[yqshao]: https://github.com/yqshao
[miniflux]: https://miniflux.app/
